==> CGMyOrders-1.1.tar.gz: CGMyOrders/method.install.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGMyOrders (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  An addon module to allow for customers to see and intereact with past
#  invoices.
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE

$fn = dirname(__FILE__).'/templates/orig_useridform_template.tpl';
if( file_exists($fn) )
  {
    $contents = file_get_contents($fn);
    $this->SetTemplate('sysdflt_useridform_template',$contents);
    $this->SetTemplate('useridform_Sample',$contents);
    $this->SetPreference('dflt_useridform_template','Sample');
  }

$fn = dirname(__FILE__).'/templates/orig_orderlist_template.tpl';
if( file_exists($fn) )
  {
    $contents = file_get_contents($fn);
    $this->SetTemplate('sysdflt_orderlist_template',$contents);
    $this->SetTemplate('orderlist_Sample',$contents);
    $this->SetPreference('dflt_orderlist_template','Sample');
  }

#
# EOF
#
?>

==> CGMyOrders-1.2.tar.gz: CGMyOrders/method.install.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGMyOrders (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  An addon module to allow for customers to see and intereact with past
#  invoices.
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE

$fn = dirname(__FILE__).'/templates/orig_useridform_template.tpl';
if( file_exists($fn) ) {
  $contents = file_get_contents($fn);
  $this->SetTemplate('sysdflt_useridform_template',$contents);
  $this->SetTemplate('useridform_Sample',$contents);
  $this->SetPreference('dflt_useridform_template','Sample');
}

$fn = dirname(__FILE__).'/templates/orig_orderlist_template.tpl';
if( file_exists($fn) ) {
  $contents = file_get_contents($fn);
  $this->SetTemplate('sysdflt_orderlist_template',$contents);
  $this->SetTemplate('orderlist_Sample',$contents);
  $this->SetPreference('dflt_orderlist_template','Sample');
}

$fn = dirname(__FILE__).'/templates/orig_reorder_template.tpl';
if( file_exists($fn) ) {
  $contents = file_get_contents($fn);
  $this->SetTemplate('sysdflt_reorder_template',$contents);
  $this->SetTemplate('reorder_Sample',$contents);
  $this->SetPreference('dflt_reorder_template','Sample');
}

#
# EOF
#
?>
